@@ -1,6 +1,9 @@
 import os
 import fnmatch
+
 from django.core.files.storage import FileSystemStorage
+from django.utils.importlib import import_module
+
 from staticfiles.settings import MEDIA_DIRNAMES, PREPEND_LABEL_APPS, \
     EXCLUDED_APPS
 
@@ -35,7 +38,7 @@ def app_static_storages(app):
         return
     # The models module may be a package in which case dirname(app.__file__)
     # would be wrong. Import the actual app as opposed to the models module.
-    app = dynamic_import(app_module) 
+    app = import_module(app_module)
     app_root = os.path.dirname(app.__file__)
     for media_dirname in MEDIA_DIRNAMES:
         location = os.path.join(app_root, media_dirname)
@@ -86,17 +89,3 @@ def get_files(storage, ignore_patterns=[], location=''):
             dir = '/'.join([location, dir])
         static_files.extend(get_files(storage, ignore_patterns, dir))
     return static_files
-
-
-def dynamic_import(import_string):
-    """
-    Dynamically import a module or object.
-    
-    """
-    # Use rfind rather than rsplit for Python 2.3 compatibility.
-    lastdot = import_string.rfind('.')
-    if lastdot == -1:
-        return __import__(import_string, {}, {}, [])
-    module_name, attr = import_string[:lastdot], import_string[lastdot + 1:]
-    parent_module = __import__(module_name, {}, {}, [attr])
-    return getattr(parent_module, attr)
